secondaryDate property
Secondary date. This date will be used when we need to define a
range of dates.
date can be starting date and secondaryDate can be end date.
Implementation
final DateTime? secondaryDate;
Secondary date. This date will be used when we need to define a
range of dates.
date can be starting date and secondaryDate can be end date.
final DateTime? secondaryDate;